@@ -1,10 +1,17 @@
 # -*- coding: utf-8 -*-
 
 from .process import Process
-from .win32.enum import ProcessOperations
-from .win32.functions import CloseProcessHandle, GetProcessHandle, ReadProcessMemory, WriteProcessMemory
+from PyMemoryEditor.win32.enums import ProcessOperationsEnum
 
-from typing import Optional, Type, TypeVar, Union
+from .win32.functions import (
+    CloseProcessHandle,
+    GetProcessHandle,
+    ReadProcessMemory,
+    SearchAllMemory,
+    WriteProcessMemory
+)
+
+from typing import Generator, Optional, Tuple, Type, TypeVar, Union
 
 
 T = TypeVar("T")
@@ -26,7 +33,7 @@ class OpenProcess(object):
         window_title: Optional[str] = None,
         process_name: Optional[str] = None,
         pid: Optional[int] = None,
-        permission: ProcessOperations = ProcessOperations.PROCESS_ALL_ACCESS
+        permission: ProcessOperationsEnum = ProcessOperationsEnum.PROCESS_ALL_ACCESS
     ):
         """
         :param window_title: window title of the target program.
@@ -62,6 +69,32 @@ class OpenProcess(object):
         """
         return CloseProcessHandle(self.__process_handle)
 
+    def search_by_value(
+        self,
+        pytype: Type[T],
+        bufflength: int,
+        value: Union[bool, int, float, str, bytes],
+        *,
+        progress_information: Optional[bool] = False,
+    ) -> Generator[Union[int, Tuple[int, dict]], None, None]:
+        """
+        Search the whole memory space, accessible to the process,
+        for the provided value, returning the found addresses.
+
+        :param pytype: type of value to be queried (bool, int, float, str or bytes).
+        :param bufflength: value size in bytes (1, 2, 4, 8).
+        :param value: value to be queried (bool, int, float, str or bytes).
+        :param progress_information: if True, a dictionary with the progress information will be return.
+        """
+        valid_permissions = [
+            ProcessOperationsEnum.PROCESS_ALL_ACCESS.value,
+            ProcessOperationsEnum.PROCESS_VM_READ.value
+        ]
+        if self.__permission.value not in valid_permissions:
+            raise PermissionError("The handle does not have permission to read the process memory.")
+
+        return SearchAllMemory(self.__process_handle, pytype, bufflength, value, progress_information)
+
     def read_process_memory(
         self,
         address: int,
@@ -76,8 +109,8 @@ class OpenProcess(object):
         :param bufflength: value size in bytes (1, 2, 4, 8).
         """
         valid_permissions = [
-            ProcessOperations.PROCESS_ALL_ACCESS.value,
-            ProcessOperations.PROCESS_VM_READ.value
+            ProcessOperationsEnum.PROCESS_ALL_ACCESS.value,
+            ProcessOperationsEnum.PROCESS_VM_READ.value
         ]
         if self.__permission.value not in valid_permissions:
             raise PermissionError("The handle does not have permission to read the process memory.")
@@ -100,8 +133,8 @@ class OpenProcess(object):
         :param value: value to be written (bool, int, float, str or bytes).
         """
         valid_permissions = [
-            ProcessOperations.PROCESS_ALL_ACCESS.value,
-            ProcessOperations.PROCESS_VM_OPERATION.value | ProcessOperations.PROCESS_VM_WRITE.value
+            ProcessOperationsEnum.PROCESS_ALL_ACCESS.value,
+            ProcessOperationsEnum.PROCESS_VM_OPERATION.value | ProcessOperationsEnum.PROCESS_VM_WRITE.value
         ]
         if self.__permission.value not in valid_permissions:
             raise PermissionError("The handle does not have permission to write to the process memory.")
